.. Ladybug Comfort documentation master file, created by
   sphinx-quickstart on Wed Mar 13 20:09:41 2019.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to Ladybug Comfort's documentation!
===================================

.. toctree::
   :maxdepth: 2
   :caption: Contents:

.. include:: modules.rst


Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
